@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.14'
+__version__ = '0.1.15'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -582,6 +582,6 @@ class HelpAppBase(MainAppBase, ABC):
 
     def on_flow_popup_close(self, _flow_key: str, _popup_args: Dict[str, Any]) -> bool:
         """ overwritten popup close handler of FlowPopup widget for to reset help widget/text. """
-        if self.help_layout:
+        if self.help_layout and self.help_widget(self.displayed_help_id, dict()) is self.help_activator:
             self.help_display('', dict())
         return True
